# Overview
Module featuring RangeCollection object class for the management of range data and optimized performance of various simple and complex range operations, including range and point overlays, equitable and score-based separation of overlapping ranges, generation of random range data, and range data comparisons among others.

# Release Notes
## 0.0.5 (2022-09-02)
- Added balance option to from_steps method
- Various minor feature additions
- Various bug fixes, performance improvements

## 0.0.4 (2022-04-11)
- Added snapping to set_centers and __init__ methods
- Added squeeze parameter to intersecting method
- Various bug fixes, performance improvements

## 0.0.3 (2021-11-08)
- Initial updated merging features
- Various bug fixes, performance improvements

## 0.0.2 (2021-09-27)
- Various bug fixes, performance improvements

## 0.0.1 (2021-09-13)
- Initial release
